@@ -281,6 +281,10 @@ def _health_check(host: str, port: int):
         if resp.ok:
             break
         else:
+            if resp.status_code in (400, 404):
+                # this is not indicative of unhealthy server
+                # but rather it wants a dbt project to be registered
+                break
             logger().critical(error_msg, address)
             raise ConnectionError(error_msg)
     return resp.json()
@@ -414,11 +418,12 @@ def register_project(
     params = {"project_dir": project_dir, "profiles_dir": profiles_dir, "force": True}
     if target:
         params["target"] = target
-    endpoint = f"http://{host}:{port}/register?{urlencode(params)}"
+    endpoint = f"http://{host}:{port}/register"
     logger().info("Registering project: %s", endpoint)
     res = requests.post(
         endpoint,
         headers={"X-dbt-Project": project_name or str(Path(project_dir).absolute())},
+        json={"project_dir": project_dir, "profiles_dir": profiles_dir, "force": True},
     )
 
     # Log
